package Bundle::Locale::CLDR::Southerneurope;

use version;

our $VERSION = version->declare('v0.40.1');

=head1 NAME

Bundle::Locale::CLDR::Southerneurope

=head1 CONTENTS

Locale::CLDR::Locales::Bs 0.40.1

Locale::CLDR::Locales::Ca 0.40.1

Locale::CLDR::Locales::De 0.40.1

Locale::CLDR::Locales::El 0.40.1

Locale::CLDR::Locales::Es 0.40.1

Locale::CLDR::Locales::Eu 0.40.1

Locale::CLDR::Locales::Gl 0.40.1

Locale::CLDR::Locales::Hr 0.40.1

Locale::CLDR::Locales::It 0.40.1

Locale::CLDR::Locales::Mk 0.40.1

Locale::CLDR::Locales::Mt 0.40.1

Locale::CLDR::Locales::Pt 0.40.1

Locale::CLDR::Locales::Sc 0.40.1

Locale::CLDR::Locales::Sl 0.40.1

Locale::CLDR::Locales::Sq 0.40.1

Locale::CLDR::Locales::Sr 0.40.1

Locale::CLDR::Locales::Ast 0.40.1

Locale::CLDR::Locales::Fur 0.40.1

Locale::CLDR::Locales::Ca::Any 0.40.1

Locale::CLDR::Locales::De::Any 0.40.1

Locale::CLDR::Locales::El::Any 0.40.1

Locale::CLDR::Locales::Es::Any 0.40.1

Locale::CLDR::Locales::Eu::Any 0.40.1

Locale::CLDR::Locales::Gl::Any 0.40.1

Locale::CLDR::Locales::Hr::Any 0.40.1

Locale::CLDR::Locales::It::Any 0.40.1

Locale::CLDR::Locales::Mk::Any 0.40.1

Locale::CLDR::Locales::Mt::Any 0.40.1

Locale::CLDR::Locales::Pt::Any 0.40.1

Locale::CLDR::Locales::Sc::Any 0.40.1

Locale::CLDR::Locales::Sl::Any 0.40.1

Locale::CLDR::Locales::Sq::Any 0.40.1

Locale::CLDR::Locales::Ast::Any 0.40.1

Locale::CLDR::Locales::Bs::Cyrl 0.40.1

Locale::CLDR::Locales::Bs::Latn 0.40.1

Locale::CLDR::Locales::Fur::Any 0.40.1

Locale::CLDR::Locales::Sr::Cyrl 0.40.1

Locale::CLDR::Locales::Sr::Latn 0.40.1

Locale::CLDR::Locales::Ca::Any::Ad 0.40.1

Locale::CLDR::Locales::Ca::Any::Es 0.40.1

Locale::CLDR::Locales::Ca::Any::It 0.40.1

Locale::CLDR::Locales::De::Any::It 0.40.1

Locale::CLDR::Locales::El::Any::Gr 0.40.1

Locale::CLDR::Locales::En::Any::Gi 0.40.1

Locale::CLDR::Locales::En::Any::Mt 0.40.1

Locale::CLDR::Locales::En::Any::Si 0.40.1

Locale::CLDR::Locales::Es::Any::Es 0.40.1

Locale::CLDR::Locales::Eu::Any::Es 0.40.1

Locale::CLDR::Locales::Gl::Any::Es 0.40.1

Locale::CLDR::Locales::Hr::Any::Ba 0.40.1

Locale::CLDR::Locales::Hr::Any::Hr 0.40.1

Locale::CLDR::Locales::It::Any::It 0.40.1

Locale::CLDR::Locales::It::Any::Sm 0.40.1

Locale::CLDR::Locales::It::Any::Va 0.40.1

Locale::CLDR::Locales::Mk::Any::Mk 0.40.1

Locale::CLDR::Locales::Mt::Any::Mt 0.40.1

Locale::CLDR::Locales::Pt::Any::Pt 0.40.1

Locale::CLDR::Locales::Sc::Any::It 0.40.1

Locale::CLDR::Locales::Sl::Any::Si 0.40.1

Locale::CLDR::Locales::Sq::Any::Al 0.40.1

Locale::CLDR::Locales::Sq::Any::Mk 0.40.1

Locale::CLDR::Locales::Sq::Any::Xk 0.40.1

Locale::CLDR::Locales::Ast::Any::Es 0.40.1

Locale::CLDR::Locales::Bs::Cyrl::Ba 0.40.1

Locale::CLDR::Locales::Bs::Latn::Ba 0.40.1

Locale::CLDR::Locales::En::Any::001 0.40.1

Locale::CLDR::Locales::En::Any::150 0.40.1

Locale::CLDR::Locales::Fur::Any::It 0.40.1

Locale::CLDR::Locales::Sr::Cyrl::Ba 0.40.1

Locale::CLDR::Locales::Sr::Cyrl::Me 0.40.1

Locale::CLDR::Locales::Sr::Cyrl::Rs 0.40.1

Locale::CLDR::Locales::Sr::Cyrl::Xk 0.40.1

Locale::CLDR::Locales::Sr::Latn::Ba 0.40.1

Locale::CLDR::Locales::Sr::Latn::Me 0.40.1

Locale::CLDR::Locales::Sr::Latn::Rs 0.40.1

Locale::CLDR::Locales::Sr::Latn::Xk 0.40.1


=cut

1;

